function [] = make_all_partial_derivates_C_and_D_matrices()
    G = create_coplanarity_equation();
    
    G_d_by=derive_G_d_by() %partial derivative of fy with respect to omega
    G_d_bz=derive_G_d_bz() %partial derivative of fx with respect to phi
    G_d_o2=derive_G_d_o2() %partial derivative of fy with respect to phi
    G_d_p2=derive_G_d_p2() %partial derivative of fx with respect to kappa
    G_d_k2=derive_G_d_k2() %partial derivative of fy with respect to kappa
    G_d_x1=derive_G_d_x1() %partial derivative of fx with respect to X0
    G_d_y1=derive_G_d_y1() %partial derivative of fy with respect to X0
    G_d_x2=derive_G_d_x2() %partial derivative of fx with respect to Y0
    G_d_y2=derive_G_d_y2() %partial derivative of fy with respect to Y0

    
    %Writing the results as functions
    fileID = fopen('partial_derivatives_RO.m','w');
    fprintf(fileID,'function [G] = coplanarity_equation(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G=%s;\r\nend\r\n',char(G)); 
    fprintf(fileID,'function [G_d_by] = make_G_d_by(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_by=%s;\r\nend\r\n',char(G_d_by)); 
    fprintf(fileID,'function [G_d_bz] = make_G_d_bz(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_bz=%s;\r\nend\r\n',char(G_d_bz)); 
    fprintf(fileID,'function [G_d_o2] = make_G_d_o2(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_o2=%s;\r\nend\r\n',char(G_d_o2)); 
    fprintf(fileID,'function [G_d_p2] = make_G_d_p2(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_p2=%s;\r\nend\r\n',char(G_d_p2));
    fprintf(fileID,'function [G_d_k2] = make_G_d_k2(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_k2=%s;\r\nend\r\n',char(G_d_k2));
    fprintf(fileID,'function [G_d_x1] = make_G_d_x1(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_x1=%s;\r\nend\r\n',char(G_d_x1));
    fprintf(fileID,'function [G_d_y1] = make_G_d_y1(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_y1=%s;\r\nend\r\n',char(G_d_y1)); 
    fprintf(fileID,'function [G_d_x2] = make_G_d_x2(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_x2=%s;\r\nend\r\n',char(G_d_x2));
    fprintf(fileID,'function [G_d_y2] = make_G_d_y2(c,bx,by,bz,o2,p2,k2,x1,y1,x2,y2)\r\n G_d_y2=%s;\r\nend\r\n',char(G_d_y2)); 
    fclose(fileID);
end

function [G] = create_coplanarity_equation()
syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

%3D rotation matrix from the image space to object space

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);

U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c]; 
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);
%set o1, p1, k1 zeros
G=subs(G, o1, 0);
G=subs(G, p1, 0);
G=subs(G, k1, 0);

end


function [ G_d_by ] = derive_G_d_by()
%this function crates symbolic equation for partial derivative with respect
%to omega from the upper collinearity equation fx

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c]; 
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_by=diff(G,by);

%set o1, p1, k1 zeros
G_d_by=subs(G_d_by, o1, 0);
G_d_by=subs(G_d_by, p1, 0);
G_d_by=subs(G_d_by, k1, 0);

%G_d_by=simplify(G_d_by) %gives the same result in this case

end

function [ G_d_bz ] = derive_G_d_bz()
%this function crates symbolic equation for partial derivative with respect
%to omega from the upper collinearity equation fy

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c] ;
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_bz=diff(G,bz);
%set o1, p1, k1 zeros
G_d_bz=subs(G_d_bz, o1, 0);
G_d_bz=subs(G_d_bz, p1, 0);
G_d_bz=subs(G_d_bz, k1, 0);

end

function [ G_d_o2 ] = derive_G_d_o2()
%this function crates symbolic equation for partial derivative with respect
%to phi from the upper collinearity equation fx

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c] ;
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_o2=diff(G,o2);
%set o1, p1, k1 zeros
G_d_o2=subs(G_d_o2, o1, 0);
G_d_o2=subs(G_d_o2, p1, 0);
G_d_o2=subs(G_d_o2, k1, 0);

end

function [ G_d_p2 ] = derive_G_d_p2()
%this function crates symbolic equation for partial derivative with respect
%to phi from the upper collinearity equation fy

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);


U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c] ;
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_p2=diff(G,p2);
%set o1, p1, k1 zeros
G_d_p2=subs(G_d_p2, o1, 0);
G_d_p2=subs(G_d_p2, p1, 0);
G_d_p2=subs(G_d_p2, k1, 0);

%fx_d_o=simplify(fx_d_o) %gives the same result in this case

end

function [ G_d_k2 ] = derive_G_d_k2()
%this function crates symbolic equation for partial derivative with respect
%to kappa from the upper collinearity equation fx

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c] ;
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_k2=diff(G,k2);
%set o1, p1, k1 zeros
G_d_k2=subs(G_d_k2, o1, 0);
G_d_k2=subs(G_d_k2, p1, 0);
G_d_k2=subs(G_d_k2, k1, 0);

end


function [ G_d_x1 ] = derive_G_d_x1()
%this function crates symbolic equation for partial derivative with respect
%to kappa from the upper collinearity equation fy

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);


U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c] ;
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_x1=diff(G,x1);
%set o1, p1, k1 zeros
G_d_x1=subs(G_d_x1, o1, 0);
G_d_x1=subs(G_d_x1, p1, 0);
G_d_x1=subs(G_d_x1, k1, 0);

end

function [ G_d_y1 ] = derive_G_d_y1()
%this function crates symbolic equation for partial derivative with respect
%to X0 from the upper collinearity equation fx

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c]; 
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_y1=diff(G,y1);
%set o1, p1, k1 zeros
G_d_y1=subs(G_d_y1, o1, 0);
G_d_y1=subs(G_d_y1, p1, 0);
G_d_y1=subs(G_d_y1, k1, 0);

end

function [ G_d_x2 ] = derive_G_d_x2()
%this function crates symbolic equation for partial derivative with respect
%to X0 from the upper collinearity equation fy

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c]; 
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_x2=diff(G,x2);
%set o1, p1, k1 zeros
G_d_x2=subs(G_d_x2, o1, 0);
G_d_x2=subs(G_d_x2, p1, 0);
G_d_x2=subs(G_d_x2, k1, 0);

end

function [ G_d_y2 ] = derive_G_d_y2()
%this function crates symbolic equation for partial derivative with respect
%to Y0 from the upper collinearity equation fx

%define a variables as symbols

syms o1 p1 k1  c ;
syms r11_1 r12_1 r13_1 r21_1 r22_1 r23_1 r31_1 r32_1 r33_1;
syms x1 y1 X1 Y1 Z1;

syms o2 p2 k2;
syms r11_2 r12_2 r13_2 r21_2 r22_2 r23_2 r31_2 r32_2 r33_2;
syms x2 y2 X2 Y2 Z2;

syms bx by bz;

r11_1=cos(p1)*cos(k1);
r12_1=-cos(p1)*sin(k1);
r13_1=sin(p1);
r21_1=cos(o1)*sin(k1)+sin(o1)*sin(p1)*cos(k1);
r22_1=cos(o1)*cos(k1)-sin(o1)*sin(p1)*sin(k1);
r23_1=-sin(o1)*cos(p1);
r31_1=sin(o1)*sin(k1)-cos(o1)*sin(p1)*cos(k1);
r32_1=sin(o1)*cos(k1)+cos(o1)*sin(p1)*sin(k1);
r33_1=cos(o1)*cos(p1);

r11_2=cos(p2)*cos(k2);
r12_2=-cos(p2)*sin(k2);
r13_2=sin(p2);
r21_2=cos(o2)*sin(k2)+sin(o2)*sin(p2)*cos(k2);
r22_2=cos(o2)*cos(k2)-sin(o2)*sin(p2)*sin(k2);
r23_2=-sin(o2)*cos(p2);
r31_2=sin(o2)*sin(k2)-cos(o2)*sin(p2)*cos(k2);
r32_2=sin(o2)*cos(k2)+cos(o2)*sin(p2)*sin(k2);
r33_2=cos(o2)*cos(p2);



U1=[r11_1 r12_1 r13_1;r21_1 r22_1 r23_1;r31_1 r32_1 r33_1]*[x1;y1;-c]; 
X1=U1(1);
Y1=U1(2);
Z1=U1(3);
U2=[r11_2 r12_2 r13_2;r21_2 r22_2 r23_2;r31_2 r32_2 r33_2]*[x2;y2;-c];
X2=U2(1);
Y2=U2(2);
Z2=U2(3);
G=bx*(Y1*Z2-Y2*Z1)-by*(X1*Z2-X2*Z1)+bz*(X1*Y2-X2*Y1);

G_d_y2=diff(G,y2);
%set o1, p1, k1 zeros
G_d_y2=subs(G_d_y2, o1, 0);
G_d_y2=subs(G_d_y2, p1, 0);
G_d_y2=subs(G_d_y2, k1, 0);
end

